"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isNotConsumedPurchase = exports.getPurchase = exports.init = void 0;
const appHttp = __importStar(require("../components/app-http"));
const appStorage = __importStar(require("../components/app-storage"));
const utils_1 = require("../utils/utils");
const init = (initialData) => {
    appStorage.saveInitialData(initialData);
};
exports.init = init;
const isNotConsumedPurchase = (purchase) => __awaiter(void 0, void 0, void 0, function* () {
    return new Promise((resolve, reject) => __awaiter(void 0, void 0, void 0, function* () {
        if (!purchase.packageName.trim()) {
            return reject("Package name is invalid.");
        }
        if (!purchase.productId.trim()) {
            return reject("Product is not found.");
        }
        if (!purchase.purchaseToken.trim()) {
            return reject("The requested purchase is not found!");
        }
        try {
            const response = yield getPurchase(purchase);
            resolve(response.consumptionState == 1);
        }
        catch (e) {
            reject(e);
        }
    }));
});
exports.isNotConsumedPurchase = isNotConsumedPurchase;
const getPurchase = (purchase) => __awaiter(void 0, void 0, void 0, function* () {
    return new Promise((resolve, reject) => {
        tryToGetPurchase(purchase, {
            onSuccess: (response) => {
                resolve(response);
            },
            onUnauthorized: () => {
                updateAccessToken()
                    .then(() => {
                    tryToGetPurchase(purchase, {
                        onSuccess: (response) => {
                            resolve(response);
                        },
                        onFailure: (error) => {
                            reject(error);
                        },
                    });
                })
                    .catch((error) => {
                    reject(error);
                });
            },
            onFailure: (error) => {
                reject(error);
            },
        });
    });
});
exports.getPurchase = getPurchase;
const tryToGetPurchase = (purchaseValue, appResponse) => {
    const url = `https://pardakht.cafebazaar.ir/devapi/v2/api/validate/${purchaseValue.packageName}/inapp/${purchaseValue.productId}/purchases/${purchaseValue.purchaseToken}?access_token=${appStorage.getAccessToken()}`;
    (0, utils_1.appLog)(`Try to validate purchase '${purchaseValue.productId}'...`);
    appHttp.post({ url }, {
        onSuccess: (response) => {
            appResponse.onSuccess(response);
        },
        onUnauthorized: () => {
            var _a;
            (_a = appResponse.onUnauthorized) === null || _a === void 0 ? void 0 : _a.call(appResponse);
        },
        onFailure: (error) => {
            appResponse.onFailure(error);
        },
    });
};
const updateAccessToken = () => __awaiter(void 0, void 0, void 0, function* () {
    return new Promise((resolve, reject) => __awaiter(void 0, void 0, void 0, function* () {
        const initialData = appStorage.getInitialData();
        const formData = new URLSearchParams();
        formData.append("grant_type", "refresh_token");
        formData.append("client_id", initialData.clientId);
        formData.append("client_secret", initialData.clientSecret);
        formData.append("refresh_token", initialData.refreshToken);
        const url = "https://pardakht.cafebazaar.ir/devapi/v2/auth/token/";
        appHttp.post({ url, data: formData }, {
            onSuccess: (response) => {
                appStorage.updateAccessToken(response.access_token);
                resolve();
            },
            onFailure: (error) => {
                reject(error);
            },
        });
    }));
});
